@@ -3,14 +3,17 @@ if ( defined('ABSPATH') )
 	require_once( ABSPATH . 'wp-config.php');
 else
     require_once('../wp-config.php');
+
+if ( get_option('db_version') != $wp_db_version )
+	die (sprintf(__("Your database is out-of-date.  Please <a href='%s'>upgrade</a>."), get_option('siteurl') . '/wp-admin/upgrade.php'));
     
 require_once(ABSPATH . 'wp-admin/admin-functions.php');
+require_once(ABSPATH . 'wp-admin/admin-db.php');
+require_once(ABSPATH . WPINC . '/registration-functions.php');
+
 auth_redirect();
 
-header('Expires: Wed, 11 Jan 1984 05:00:00 GMT');
-header('Last-Modified: ' . gmdate('D, d M Y H:i:s') . ' GMT');
-header('Cache-Control: no-cache, must-revalidate, max-age=0');
-header('Pragma: no-cache');
+nocache_headers();
 
 update_category_cache();
 
@@ -41,7 +44,8 @@ require(ABSPATH . '/wp-admin/menu.php');
 
 // Handle plugin admin pages.
 if (isset($_GET['page'])) {
-	$plugin_page = plugin_basename($_GET['page']);
+	$plugin_page = stripslashes($_GET['page']);
+	$plugin_page = plugin_basename($plugin_page);
 	$page_hook = get_plugin_page_hook($plugin_page, $pagenow);
 
 	if ( $page_hook ) {
@@ -65,7 +69,36 @@ if (isset($_GET['page'])) {
 	
 	include(ABSPATH . 'wp-admin/admin-footer.php');
 
+	exit();
+} else if (isset($_GET['import'])) {
+	
+	$importer = $_GET['import'];
+
+	if ( validate_file($importer) ) {
+		die(__('Invalid importer.'));
+	}
+		
+	if (! file_exists(ABSPATH . "wp-admin/import/$importer.php"))
+		die(__('Cannot load importer.'));
+	
+	include(ABSPATH . "wp-admin/import/$importer.php");
+
+	$parent_file = 'import.php';
+	$title = __('Import');
+	
+	if (! isset($_GET['noheader']))
+		require_once(ABSPATH . 'wp-admin/admin-header.php');
+
+	require_once(ABSPATH . 'wp-admin/upgrade-functions.php');
+
+	define('WP_IMPORTING', true);
+	kses_init_filters();  // Always filter imported data with kses.
+
+	call_user_func($wp_importers[$importer][2]);
+			
+	include(ABSPATH . 'wp-admin/admin-footer.php');
+
 	exit();
 }
 
-?>
\ No newline at end of file
+?>
